Option Explicit On 
Option Strict On

Imports System.Runtime.InteropServices
Imports System
Imports System.Data
Imports System.EnterpriseServices
Imports System.Diagnostics
Imports System.Data.SqlClient
Imports Quilogy.Education.Schedule

Namespace Quilogy.Education.Enrollment

  '<Transaction(TransactionOption.Required)> _
  Public Class Registration ': Inherits QuilogyDataAccessBase
#Region "Hidden"
    'Private objLog As QuilogyLog
    Private strConnect As String


    Public Sub New()
      '   objLog = New QuilogyLog()
      '   objLog.LogFile = "Registrations.log"
    End Sub
    Public Sub New(ByVal connect As String)
      strConnect = connect
    End Sub
#End Region
    Public Function RegisterStudent( _
      ByVal enroll As EnrollmentData) As Integer

      Dim arStud(), arContact() As DataRow
      Dim drStud, drEnroll As DataRow
      Dim intStudentID, intClassID, intEnrollID As Integer
      Dim strEmail, strLastName As String
      Dim objStudents As Students
      Dim dsStudents As StudentData
      Dim decCost As Decimal
      Dim objClasses As New Classes(strConnect)
      'Dim objEmail As Email

      ' Implement the business process for registering the student

      If enroll Is Nothing Then
        'ContextUtil.SetAbort()
        Throw New ArgumentNullException("No enrollment data found")
      End If

      ' Validate Student
      drEnroll = enroll.EnrollmentTable.Rows(0)
      intClassID = Convert.ToInt32(drEnroll(EnrollmentData.CLASS_ID))

      If intClassID = 0 Then
        'ContextUtil.SetAbort()
        Throw New ArgumentOutOfRangeException("Must provide a classID")
      End If

      ' Make sure the class is not full
      If objClasses.IsFull(intClassID) Then
        'ContextUtil.SetAbort()
        Throw New Exception("Class is already full")
      End If

      ' Get the student info
      Try
        arStud = drEnroll.GetChildRows("Enrollment_Student")
        drStud = arStud(0)
        intStudentID = Convert.ToInt32(drStud(EnrollmentData.STUDENT_ID))

        If intStudentID = 0 Then
          ' Check if student exists
          arContact = drStud.GetChildRows("Student_ContactInfo")
          strEmail = arContact(0).Item(EnrollmentData.EMAIL).ToString
          strLastName = arContact(0).Item(EnrollmentData.LAST_NAME).ToString

          objStudents = New Students(strConnect)
          intStudentID = objStudents.CheckIfExists(strEmail, strLastName)

          If intStudentID = 0 Then
            ' Student did not exist
            ' Build the new student data structure
            dsStudents = New StudentData()
            drStud = dsStudents.StudentTable.NewRow()
            With drStud
              .Item(StudentData.FIRST_NAME) = _
                arContact(0).Item(EnrollmentData.FIRST_NAME)
              .Item(StudentData.LAST_NAME) = strLastName
              .Item(StudentData.ORGANIZATION) = _
                arContact(0).Item(EnrollmentData.ORGANIZATION)
              .Item(StudentData.EMAIL) = strEmail
              .Item(StudentData.ADDRESS) = _
                arContact(0).Item(EnrollmentData.ADDRESS)
              .Item(StudentData.CITY) = arContact(0).Item(EnrollmentData.CITY)
              .Item(StudentData.STATE) = _
                arContact(0).Item(EnrollmentData.STATE)
              .Item(StudentData.ZIP_CODE) = _
                arContact(0).Item(EnrollmentData.ZIP_CODE)
              .Item(StudentData.PHONE) = _
                arContact(0).Item(EnrollmentData.PHONE)
            End With
            ' Save the student
            intStudentID = objStudents.Save(dsStudents)
          End If

          ' Set the student id in the enrollment data
          drStud(EnrollmentData.STUDENT_ID) = intStudentID
        End If

      Catch e As Exception
        'ContextUtil.SetAbort()
        Dim newE As New Exception( _
          "Student could not be validated or saved. ", e)
        Throw (newE)
      End Try

      Try
        ' Calculate the cost
        decCost = Convert.ToDecimal(objClasses.CalcCost(intClassID, _
          RegistrationType.Web))
        drEnroll(EnrollmentData.COST) = decCost
        ' Persist the registration
        intEnrollID = objClasses.AddEnrollment(enroll)
        Return intEnrollID

      Catch e As Exception
        'ContextUtil.SetAbort()
        Dim newE As New Exception( _
          "Could not calculate the cost.", e)
        Throw (newE)
      End Try

      ' Email verification to student
      'Try
      '                Thread.CurrentThread.ApartmentState = ApartmentState.STA
      'objEmail = New Email()
      'objEmail.SendEnrollVerify(intEnrollID, objClasses.ConstructString)
      'Catch e As Exception
      ' Not critical so don't rollback transaction
      '                objLog.LogText("Email not sent: " & e.Message, True)
      'End Try

      'ContextUtil.SetComplete()
      Return intEnrollID

    End Function

  End Class
End Namespace

