Option Strict On
Option Explicit On 

Imports System
Imports System.Data
Imports System.Runtime.Serialization

Namespace Quilogy.Education
  <Serializable()> _
Public Class EnrollmentData : Inherits DataSet

    Private enrollment As DataTable
    Private student As DataTable
    Private contactInfo As DataTable
    Private enrollmentStudent As DataRelation
    Private studentContactInfo As DataRelation

    ' Enrollment table
    Public Const CLASS_ID As String = "ClassID"
    Public Const WEB_ENROLL As String = "WebEnroll"
    Public Const PAYMENT_TYPE As String = "PaymentType"
    Public Const COST As String = "Cost"

    ' Student table
    Public Const STUDENT_ID As String = "StudentID"
    Public Const FIRST_NAME As String = "FName"
    Public Const LAST_NAME As String = "LName"
    Public Const ORGANIZATION As String = "Organization"
    Public Const COMMENTS As String = "Comments"
    Public Const EXISTING As String = "Existing"

    ' Contact Info table
    Public Const ADDRESS As String = "Address"
    Public Const EMAIL As String = "Email"
    Public Const CITY As String = "City"
    Public Const STATE As String = "State"
    Public Const ZIP_CODE As String = "ZipCode"
    Public Const PHONE As String = "Phone"

    Public Sub New()
      '   Initialize an EnrollmentData instance by building the tables              
      MyBase.New()
      InitClass()
    End Sub

    Public Sub New(ByVal info As SerializationInfo, ByVal context As StreamingContext)
      '   Initialize a TranscriptData instance 
      MyBase.New()
      InitClass()
      Me.GetSerializationData(info, context)
    End Sub

    Private Sub InitClass()
      ' Create the tables in the dataset
      BuildTables()
      AddRelations()

      ' Initialize the class
      Me.DataSetName = "QuilogyEnrollment"
      Me.Namespace = "www.quilogy.com/education/registration"
      Me.Prefix = "qedr"
      Me.CaseSensitive = False
    End Sub

    Public ReadOnly Property EnrollmentTable() As DataTable
      Get
        Return enrollment
      End Get
    End Property

    Private Sub AddRelations()

      ' Add the foreign keys
      student.Constraints.Add(New ForeignKeyConstraint("Enrollment_Student", _
     enrollment.Columns("Enroll_Id"), student.Columns("Enroll_Id")))

      contactInfo.Constraints.Add(New ForeignKeyConstraint("Student_ContactInfo", _
     student.Columns("Student_Id"), contactInfo.Columns("Student_Id")))

      ' Add the data relations
      enrollmentStudent = New DataRelation("Enrollment_Student", _
     enrollment.Columns("Enroll_Id"), student.Columns("Enroll_Id"))

      enrollmentStudent.Nested = True
      Me.Relations.Add(enrollmentStudent)

      studentContactInfo = New DataRelation("Student_ContactInfo", _
     student.Columns("Student_Id"), contactInfo.Columns("Student_Id"))

      studentContactInfo.Nested = True
      Me.Relations.Add(studentContactInfo)

    End Sub

    Private Sub BuildTables()

      ' Create the enrollment tables
      enrollment = New DataTable("Enrollment")
      With enrollment.Columns
        .Add("Enroll_Id", GetType(System.Int32))
        .Add(CLASS_ID, GetType(System.Int32))
        .Add(WEB_ENROLL, GetType(System.String))
        .Add(PAYMENT_TYPE, GetType(System.String))
        .Add(COST, GetType(System.Decimal))
      End With

      student = New DataTable("Student")
      With student.Columns
        .Add("Enroll_Id", GetType(System.Int32))
        .Add("Student_Id", GetType(System.Int32))
        .Add(STUDENT_ID, GetType(System.Int32))
        .Add(FIRST_NAME, GetType(System.String))
        .Add(LAST_NAME, GetType(System.String))
        .Add(ORGANIZATION, GetType(System.String))
        .Add(COMMENTS, GetType(System.String))
        .Add(EXISTING, GetType(System.String))
      End With

      contactInfo = New DataTable("ContactInfo")
      With contactInfo.Columns
        .Add("Student_Id", GetType(System.Int32))
        .Add(ADDRESS, GetType(System.String))
        .Add(CITY, GetType(System.String))
        .Add(STATE, GetType(System.String))
        .Add(ZIP_CODE, GetType(System.String))
        .Add(PHONE, GetType(System.String))
        .Add(EMAIL, GetType(System.String))
      End With


      ' Set the column attributes
      With enrollment
        .Columns("Enroll_Id").ColumnMapping = MappingType.Hidden
        .Columns("Enroll_Id").AutoIncrement = True
        .Columns("Enroll_Id").AllowDBNull = False
        .Columns("Enroll_Id").Unique = True
        .Columns(CLASS_ID).ColumnMapping = MappingType.Attribute
        .Columns(WEB_ENROLL).ColumnMapping = MappingType.Attribute
        .Columns(PAYMENT_TYPE).ColumnMapping = MappingType.Attribute
        .Columns(CLASS_ID).AllowDBNull = False
        .Columns(WEB_ENROLL).AllowDBNull = False
        .Columns(PAYMENT_TYPE).AllowDBNull = False
        .PrimaryKey = New DataColumn() {.Columns("Enroll_Id")}
      End With

      ' Set the column attributes
      With student
        .Columns("Enroll_Id").ColumnMapping = MappingType.Hidden
        .Columns("Student_Id").ColumnMapping = MappingType.Hidden
        .Columns("Student_Id").AutoIncrement = True
        .Columns("Student_Id").AllowDBNull = False
        .Columns("Student_Id").Unique = True
        .Columns(STUDENT_ID).ColumnMapping = MappingType.Attribute
        .Columns(EXISTING).ColumnMapping = MappingType.Attribute
        .Columns(LAST_NAME).AllowDBNull = False
        .Columns(LAST_NAME).Caption = "Last Name"
        .Columns(FIRST_NAME).Caption = "First Name"
        .Columns(ORGANIZATION).Caption = "Organization"
        .PrimaryKey = New DataColumn() {.Columns("Student_Id")}
      End With

      ' Set the column attributes
      With contactInfo
        .Columns("Student_Id").ColumnMapping = MappingType.Hidden
        .Columns(ZIP_CODE).Caption = "Postal Code"
      End With

      ' Add the table to the collection
      Me.Tables.Add(enrollment)
      Me.Tables.Add(student)
      Me.Tables.Add(contactInfo)
    End Sub
  End Class
End Namespace

