Option Strict On
Option Explicit On 

Imports System
Imports System.Data
Imports System.Runtime.Serialization

Namespace Quilogy.Education

  <Serializable()> _
  Public Class StudentData : Inherits DataSet

    Private student As DataTable

    Public Const STUDENT_ID As String = "StudentID"
    Public Const FIRST_NAME As String = "FName"
    Public Const LAST_NAME As String = "LName"
    Public Const ORGANIZATION As String = "Organization"
    Public Const ADDRESS As String = "Address"
    Public Const EMAIL As String = "Email"
    Public Const CITY As String = "City"
    Public Const STATE As String = "State"
    Public Const ZIP_CODE As String = "ZipCode"
    Public Const PHONE As String = "Phone"

    Public Sub New()
      '   Initialize a StudentData instance by building the table              
      MyBase.New()
      InitClass()
    End Sub

    Public Sub New(ByVal info As SerializationInfo, ByVal context As StreamingContext)
      '   Initialize a TranscriptData instance 
      MyBase.New()
      InitClass()
      Me.GetSerializationData(info, context)
    End Sub

    Private Sub InitClass()
      ' Create the tables in the dataset
      BuildTables()

      ' Initialize the class
      Me.DataSetName = "QuilogyStudent"
      Me.Namespace = "www.quilogy.com/education/student"
      Me.Prefix = "qedst"
      Me.CaseSensitive = False
    End Sub

    Public ReadOnly Property StudentTable() As DataTable
      Get
        Return student
      End Get
    End Property

    Private Sub BuildTables()

      ' Create the transcript table
      student = New DataTable("Student")

      With student.Columns
        .Add(STUDENT_ID, GetType(System.Int32))
        .Add(FIRST_NAME, GetType(System.String))
        .Add(LAST_NAME, GetType(System.String))
        .Add(ORGANIZATION, GetType(System.String))
        .Add(EMAIL, GetType(System.String))
        .Add(ADDRESS, GetType(System.String))
        .Add(CITY, GetType(System.String))
        .Add(STATE, GetType(System.String))
        .Add(ZIP_CODE, GetType(System.String))
        .Add(PHONE, GetType(System.String))
      End With

      ' Set the column attributes
      With student
        .Columns(STUDENT_ID).ColumnMapping = MappingType.Attribute
        .Columns(STUDENT_ID).Unique = True
        .Columns(LAST_NAME).AllowDBNull = False
        .Columns(LAST_NAME).Caption = "Last Name"
        .Columns(FIRST_NAME).Caption = "First Name"
        .Columns(ZIP_CODE).Caption = "Postal Code"
        .Columns(ORGANIZATION).Caption = "Organization"
      End With

      ' Add the table to the collection
      Me.Tables.Add(student)

    End Sub
  End Class
End Namespace
